@@ -1,6 +1,6 @@
-/* $Id: filebuffer.cc,v 1.20.2.4 2004/05/08 20:57:59 daniel Exp $
+/* $Id: filebuffer.cc,v 1.32 2004/06/16 22:37:46 daniel Exp $
  *
- * Copyright (c) 2002  Daniel Elstner  <daniel.elstner@gmx.net>
+ * Copyright (c) 2004  Daniel Elstner  <daniel.elstner@gmx.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License VERSION 2 as
@@ -27,7 +27,7 @@
 #include "translation.h"
 
 #include <glib.h>
-#include <gconfmm.h>
+#include <gconfmm/client.h>
 #include <algorithm>
 #include <list>
 
@@ -46,7 +46,7 @@ public:
   typedef Glib::RefPtr<Gtk::TextTag> TextTagPtr;
 
   // This is a global singleton shared by all FileBuffer instances.
-  static Glib::RefPtr<RegexxerTags> instance() G_GNUC_CONST;
+  static Glib::RefPtr<RegexxerTags> instance();
 
   TextTagPtr error_message;
   TextTagPtr error_title;
@@ -75,7 +75,7 @@ RegexxerTags::RegexxerTags()
   error_title->property_scale() = Pango::SCALE_X_LARGE;
 
   Gnome::Conf::Client::get_default_client()->signal_value_changed()
-      .connect(SigC::slot(*this, &RegexxerTags::on_conf_value_changed));
+      .connect(sigc::mem_fun(*this, &RegexxerTags::on_conf_value_changed));
 
   add(error_message);
   add(error_title);
@@ -90,8 +90,6 @@ void RegexxerTags::on_conf_value_changed(const Glib::ustring& key, const Gnome::
 {
   using namespace Regexxer;
 
-  REGEXXER_GCONFMM_VALUE_HACK(value);
-
   if (value.get_type() == Gnome::Conf::VALUE_STRING)
   {
     if (key.raw() == conf_key_match_color)
@@ -196,16 +194,15 @@ FileBuffer::create_with_error_message(const Glib::RefPtr<Gdk::Pixbuf>& pixbuf,
                                       const Glib::ustring& message)
 {
   const Glib::RefPtr<FileBuffer> buffer (new FileBuffer());
-
   const Glib::RefPtr<RegexxerTags> tagtable = RegexxerTags::instance();
-  iterator pend = buffer->end();
+
+  iterator pend = buffer->insert_pixbuf(buffer->end(), pixbuf);
 
   Glib::ustring title = "\302\240";
   // TRANSLATORS: Please replace space by U+00A0 NO-BREAK SPACE.
   title += _("Can't read file:");
   title += '\n';
 
-  pend = buffer->insert_pixbuf(pend, pixbuf);
   pend = buffer->insert_with_tag(pend, title, tagtable->error_title);
   pend = buffer->insert(pend, message);
 
@@ -266,7 +263,6 @@ int FileBuffer::find_matches(Pcre::Pattern& pattern, bool multiple)
 {
   ScopedLock lock (*this);
 
-  const Glib::RefPtr<Glib::MainContext> main_context = Glib::MainContext::get_default();
   const Glib::RefPtr<RegexxerTags> tagtable = RegexxerTags::instance();
 
   notify_weak_undos();
@@ -331,7 +327,7 @@ int FileBuffer::find_matches(Pcre::Pattern& pattern, bool multiple)
       const MatchDataPtr match (new MatchData(
           original_match_count_, subject, pattern, capture_count));
 
-      match_set_.insert(match_set_.end(), match); // triggers on_insert()
+      match_set_.insert(match_set_.end(), match);
       match->install_mark(start);
 
       apply_tag(tagtable->match, start, stop);
@@ -353,10 +349,7 @@ int FileBuffer::get_match_count() const
 
 int FileBuffer::get_match_index() const
 {
-  // Stupid work-around for silly, silly gcc 2.95.x.
-  const MatchSet::const_iterator current_match (current_match_);
-
-  return (!match_removed_ && current_match != match_set_.end()) ? (*current_match)->index : 0;
+  return (!match_removed_ && current_match_ != match_set_.end()) ? (*current_match_)->index : 0;
 }
 
 int FileBuffer::get_original_match_count() const
@@ -497,7 +490,7 @@ int FileBuffer::get_line_preview(const Glib::ustring& substitution, Glib::ustrin
 
     // Construct the preview line: [line_begin,start) + substitution + [stop,line_end)
     result   = get_text(line_begin, start);
-    result  += Util::substitute_references(substitution.raw(), match->subject.raw(), match->captures);
+    result  += Util::substitute_references(substitution, match->subject, match->captures);
     position = result.length();
     result  += get_text(stop, line_end);
   }
@@ -541,10 +534,8 @@ void FileBuffer::undo_remove_match(const MatchDataPtr& match, int offset)
     apply_tag(tagtable->match, start, stop);
   }
 
-  if (match_removed_ && Util::prior(current_match_) == pos.first)
+  if (match_removed_ && Util::next(pos.first) == current_match_)
   {
-    remove_tag_current();
-
     current_match_ = pos.first;
     match_removed_ = false;
 
@@ -650,7 +641,7 @@ void FileBuffer::on_erase(const FileBuffer::iterator& rbegin, const FileBuffer::
       --pos;
 
       typedef std::list< Glib::RefPtr<Mark> > MarkList;
-      const MarkList marks (pos.get_marks());
+      const MarkList marks (const_cast<iterator&>(pos).get_marks());  // XXX
 
       for (MarkList::const_iterator pmark = marks.begin(); pmark != marks.end(); ++pmark)
       {
@@ -756,7 +747,7 @@ void FileBuffer::replace_match(MatchSet::const_iterator pos, const Glib::ustring
   const MatchDataPtr match = *pos;
 
   const Glib::ustring substituted_text =
-      Util::substitute_references(substitution.raw(), match->subject.raw(), match->captures);
+      Util::substitute_references(substitution, match->subject, match->captures);
 
   // Get the start of the match.
   const iterator start = match->mark->get_iter();
@@ -779,7 +770,7 @@ void FileBuffer::replace_match(MatchSet::const_iterator pos, const Glib::ustring
     }
 
     // Manually remove match mark and insert the new text.
-    delete_mark(match->mark);        // triggers on_mark_deleted()
+    delete_mark(match->mark); // triggers on_mark_deleted()
 
     if (!substituted_text.empty())
       insert(start, substituted_text); // triggers on_insert()
@@ -796,7 +787,7 @@ void FileBuffer::replace_match(MatchSet::const_iterator pos, const Glib::ustring
 void FileBuffer::remove_match_at_iter(const FileBuffer::iterator& start)
 {
   typedef std::list< Glib::RefPtr<Mark> > MarkList;
-  const MarkList marks (start.get_marks());
+  const MarkList marks (const_cast<iterator&>(start).get_marks()); // XXX
 
   for (MarkList::const_iterator pmark = marks.begin(); pmark != marks.end(); ++pmark)
   {
@@ -892,7 +883,7 @@ void FileBuffer::apply_tag_current()
 bool FileBuffer::is_match_start(const iterator& where)
 {
   typedef std::list< Glib::RefPtr<Mark> > MarkList;
-  const MarkList marks (where.get_marks());
+  const MarkList marks (const_cast<iterator&>(where).get_marks()); // XXX
 
   return (std::find_if(marks.begin(), marks.end(), &MatchData::is_match_mark) != marks.end());
 }
