@@ -1,4 +1,4 @@
-/* $Id: miscutils.h,v 1.2.2.2 2004/05/05 05:41:51 daniel_e Exp $
+/* $Id: miscutils.h,v 1.4 2004/05/17 06:53:38 daniel Exp $
  *
  * Copyright (c) 2002  Daniel Elstner  <daniel.elstner@gmx.net>
  *
@@ -49,10 +49,6 @@ inline Iterator next(Iterator pos) { return ++pos; }
 template <class Iterator>
 inline Iterator prior(Iterator pos) { return --pos; }
 
-
-void check_for_broken_gconfmm_value_changed();
-bool has_broken_gconfmm_value_changed();
-
 } // namespace Util
 
 #endif /* REGEXXER_MISCUTILS_H_INCLUDED */
