@@ -1,4 +1,4 @@
-/* $Id: prefdialog.h,v 1.5.2.1 2004/05/05 03:03:03 daniel_e Exp $
+/* $Id: prefdialog.h,v 1.10 2004/05/30 09:34:50 daniel Exp $
  *
  * Copyright (c) 2002  Daniel Elstner  <daniel.elstner@gmx.net>
  *
@@ -23,14 +23,20 @@
 
 #include "signalutils.h"
 
-#include <gdkmm/color.h>
-#include <gtkmm/dialog.h>
+#include <sigc++/sigc++.h>
+#include <glibmm/ustring.h>
+#include <memory>
 
 namespace Gtk
 {
 class CheckButton;
+class ColorButton;
+class ComboBox;
+class Dialog;
 class Entry;
-class OptionMenu;
+class FontButton;
+class Widget;
+class Window;
 }
 
 namespace Gnome { namespace Conf { class Value; } }
@@ -39,43 +45,38 @@ namespace Gnome { namespace Conf { class Value; } }
 namespace Regexxer
 {
 
-class ColorSelectionButton;
-class FontSelectionButton;
-
-class PrefDialog : public Gtk::Dialog
+class PrefDialog : public sigc::trackable
 {
 public:
   explicit PrefDialog(Gtk::Window& parent);
   virtual ~PrefDialog();
 
-protected:
-  virtual void on_response(int response_id);
+  Gtk::Dialog* get_dialog() { return dialog_.get(); }
 
 private:
-  FontSelectionButton*  button_textview_font_;
-  ColorSelectionButton* button_match_color_;
-  ColorSelectionButton* button_current_color_;
-  Gtk::OptionMenu*      option_toolbar_style_;
-  Gtk::Entry*           entry_fallback_;
-  Gtk::CheckButton*     button_direction_;
-  Util::AutoConnection  conn_toolbar_style_;
-  Util::AutoConnection  conn_direction_;
-  bool                  entry_fallback_changed_;
+  std::auto_ptr<Gtk::Dialog>  dialog_;
+  Gtk::FontButton*            button_textview_font_;
+  Gtk::ColorButton*           button_match_color_;
+  Gtk::ColorButton*           button_current_color_;
+  Gtk::ComboBox*              combo_toolbar_style_;
+  Gtk::Entry*                 entry_fallback_;
+  Util::AutoConnection        conn_toolbar_style_;
+  bool                        entry_fallback_changed_;
 
-  Gtk::Widget* create_page_look();
-  Gtk::Widget* create_page_file();
+  void load_xml();
+  void connect_signals();
+
+  void on_response(int response_id);
 
-  void on_conf_value_changed_hack(const Glib::ustring& key, const Gnome::Conf::Value& value);
   void on_conf_value_changed(const Glib::ustring& key, const Gnome::Conf::Value& value);
   void initialize_configuration();
 
-  void on_textview_font_selected();
-  void on_match_color_selected();
-  void on_current_color_selected();
+  void on_textview_font_set();
+  void on_match_color_set();
+  void on_current_color_set();
   void on_option_toolbar_style_changed();
   void on_entry_fallback_changed();
   void on_entry_fallback_activate();
-  void on_button_direction_toggled();
 };
 
 } // namespace Regexxer
